@@ -31,16 +31,22 @@ class Process(Entity):
 
 
 class Interaction(Process):
-    """BioPAX Interaction."""
-    list_types = Process.list_types + ['participant']
+    """BioPAX Interaction.
+
+    Attributes
+    ----------
+    participant : List[Entity]
+    interaction_type : List[str]
+    """
+    list_types = Process.list_types + ['participant', 'interaction_type']
 
     def __init__(self,
                  participant=None,
                  interaction_type=None,
                  **kwargs):
         super().__init__(**kwargs)
-        self.participant = participant
-        self.interaction_type = interaction_type
+        self.participant = participant if participant else []
+        self.interaction_type = interaction_type if interaction_type else []
 
 
 class GeneticInteraction(Interaction):
@@ -54,7 +60,14 @@ class MolecularInteraction(Interaction):
 
 
 class TemplateReaction(Interaction):
-    """BioPAX TemplateReaction."""
+    """BioPAX TemplateReaction.
+
+    Attributes
+    ----------
+    template : NucleicAcid
+    product : List[PhysicalEntity]
+    template_direction : str
+    """
     list_types = Interaction.list_types + ['product']
 
     def __init__(self,
@@ -64,12 +77,19 @@ class TemplateReaction(Interaction):
                  **kwargs):
         super().__init__(**kwargs)
         self.template = template
-        self.product = product
+        self.product = product if product else []
         self.template_direction = template_direction
 
 
 class Control(Interaction):
-    """BioPAX Control."""
+    """BioPAX Control.
+
+    Attributes
+    ----------
+    control_type : str
+    controller : List[Process]
+    controlled : Process
+    """
     list_types = Interaction.list_types + ['controller']
 
     def __init__(self,
@@ -79,12 +99,21 @@ class Control(Interaction):
                  **kwargs):
         super().__init__(**kwargs)
         self.control_type = control_type
-        self.controller = controller
+        self.controller = controller if controller else []
         self.controlled = controlled
 
 
 class Conversion(Interaction):
-    """BioPAX Conversion."""
+    """BioPAX Conversion.
+
+    Attributes
+    ----------
+    left : List[PhysicalEntity]
+    right : List[PhysicalEntity]
+    conversion_direction : str
+    participant_stoichiometry : List[Stoichiometry]
+    spontaneous : bool
+    """
     list_types = Interaction.list_types + \
         ['left', 'right', 'participant_stoichiometry']
 
@@ -96,22 +125,31 @@ class Conversion(Interaction):
                  spontaneous=None,
                  **kwargs):
         super().__init__(**kwargs)
-        self.left = left
-        self.right = right
+        self.left = left if left else []
+        self.right = right if right else []
         self.conversion_direction = conversion_direction
-        self.participant_stoichiometry = participant_stoichiometry
+        self.participant_stoichiometry = participant_stoichiometry  if \
+            participant_stoichiometry else []
         self.spontaneous = spontaneous
 
 
 class Catalysis(Control):
-    """BioPAX Catalysis."""
+    """BioPAX Catalysis.
+
+    Attributes
+    ----------
+    catalysis_direction : str
+    cofactor : List[PhysicalEntity]
+    """
+    list_types = Control.list_types + ['cofactor']
+
     def __init__(self,
                  catalysis_direction=None,
                  cofactor=None,
                  **kwargs):
         super().__init__(**kwargs)
         self.catalysis_direction = catalysis_direction
-        self.cofactor = cofactor
+        self.cofactor = cofactor if cofactor else []
 
 
 class TemplateReactionRegulation(Control):
@@ -130,7 +168,19 @@ class ComplexAssembly(Conversion):
 
 
 class BiochemicalReaction(Conversion):
-    """BioPAX BiochemicalReaction."""
+    """BioPAX BiochemicalReaction.
+
+    Attributes
+    ----------
+    delta_s : List[float]
+    delta_h : List[float]
+    delta_g : List[DeltaG]
+    k_e_q : List[KPrime]
+    e_c_number : List[str]
+    """
+    list_types = Conversion.list_types + ['delta_s', 'delta_h', 'delta_g',
+                                          'k_e_q', 'e_c_number']
+
     def __init__(self,
                  delta_s=None,
                  delta_h=None,
@@ -139,11 +189,11 @@ class BiochemicalReaction(Conversion):
                  e_c_number=None,
                  **kwargs):
         super().__init__(**kwargs)
-        self.delta_s = delta_s
-        self.delta_h = delta_h
-        self.delta_g = delta_g
-        self.k_e_q = k_e_q
-        self.e_c_number = e_c_number
+        self.delta_s = delta_s if delta_s else []
+        self.delta_h = delta_h if delta_h else []
+        self.delta_g = delta_g if delta_g else []
+        self.k_e_q = k_e_q if k_e_q else []
+        self.e_c_number = e_c_number if e_c_number else []
 
 
 class Degradation(Conversion):
