@@ -7,14 +7,18 @@ from tqdm.auto import tqdm
 from . import *
 from ..xml_util import get_id_or_about, get_tag, has_ns, wrap_xml_elements
 
+default_xml_base = 'http://www.biopax.org/release/biopax-level3.owl#'
+
 
 class BioPaxModel:
     """BioPAX Model.
 
     Parameters
     ----------
-    objects : dict
-        A dict of BioPaxObject instances keyed by their URI string.
+    objects : dict or list
+        A dict of BioPaxObject instances keyed by their URI string or a list
+        of BioPaxObject instances, which will get converted into a dict keyed
+        their URI strings
     xml_base : str
         The XML base namespace for the content being represented.
 
@@ -23,12 +27,16 @@ class BioPaxModel:
     objects : dict
         A dict of BioPaxObject instances keyed by their URI string
         that are part of the model.
-    xml_base : str
-        The XML base namespace for the content being represented.
+    xml_base : Optional[str]
+        The XML base namespace for the content being represented. If not
+        provided, the default BioPAX Level 3 base namespace is used.
     """
 
-    def __init__(self, objects, xml_base):
-        self.objects = objects
+    def __init__(self, objects, xml_base=default_xml_base):
+        if isinstance(objects, list):
+            self.objects = {o.uid: o for o in objects}
+        else:
+            self.objects = objects
         self.xml_base = xml_base
         self.add_reverse_links()
 
