@@ -9,7 +9,15 @@ from .util import EntityFeature, EntityReference
 
 
 class PhysicalEntity(Entity, Controller):
-    """BioPAX PhysicalEntity."""
+    """BioPAX PhysicalEntity.
+
+    Attributes
+    ----------
+    feature : List[EntityFeature]
+    not_feature : List[EntityFeature]
+    member_physical_entity : List[PhysicalEntity]
+    cellular_location : CellularLocationVocabulary
+    """
     list_types = Entity.list_types + \
         ['feature', 'not_feature', 'member_physical_entity']
 
@@ -20,9 +28,10 @@ class PhysicalEntity(Entity, Controller):
                  cellular_location=None,
                  **kwargs):
         super().__init__(**kwargs)
-        self.feature = feature
-        self.not_feature = not_feature
-        self.member_physical_entity = member_physical_entity
+        self.feature = feature if feature else []
+        self.not_feature = not_feature if not_feature else []
+        self.member_physical_entity = member_physical_entity if \
+            member_physical_entity else []
         self.cellular_location = cellular_location
         self._component_of = set()
         self._member_physical_entity_of = set()
@@ -45,7 +54,12 @@ class PhysicalEntity(Entity, Controller):
 
 
 class SimplePhysicalEntity(PhysicalEntity):
-    """BioPAX SimplePhysicalEntity."""
+    """BioPAX SimplePhysicalEntity.
+
+    Attributes
+    ----------
+    entity_reference : EntityReference
+    """
     def __init__(
         self,
         entity_reference: Optional[EntityReference] = None,
@@ -71,7 +85,13 @@ class Rna(SimplePhysicalEntity):
 
 
 class Complex(PhysicalEntity):
-    """BioPAX Complex."""
+    """BioPAX Complex.
+
+    Attributes
+    ----------
+    component : List[PhysicalEntity]
+    component_stoichiometry : List[Stoichiometry]
+    """
     list_types = PhysicalEntity.list_types + \
         ['component', 'component_stoichiometry']
 
@@ -80,8 +100,9 @@ class Complex(PhysicalEntity):
                  component_stoichiometry: Optional[List] = None,
                  **kwargs):
         super().__init__(**kwargs)
-        self.component = component
-        self.component_stoichiometry = component_stoichiometry
+        self.component = component if component else []
+        self.component_stoichiometry = component_stoichiometry if \
+            component_stoichiometry else []
 
 
 class Dna(SimplePhysicalEntity):
